Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrExpiredToken = errors.New("token has expired") ErrInvalidToken = errors.New("token is invalid") )
Functions ¶
This section is empty.
Types ¶
type JWTMaker ¶
type JWTMaker struct {
// contains filtered or unexported fields
}
JWTMaker is a JSON Web Token Maker
func (*JWTMaker) CreateToken ¶
CreateToken creates a new token for specific username and duration
type Maker ¶
type Maker interface {
// CreateToken creates a new token for specific username and duration
CreateToken(username string, duration time.Duration) (string, error)
// VerifyToken checks if token is valid or not
VerifyToken(token string) (*Payload, error)
}
Maker is an interface for managin tokens
func NewJWTMaker ¶
NEWJWTMaker creates a new JWTMaker
func NewPasetoMaker ¶
type PasetoMaker ¶
type PasetoMaker struct {
// contains filtered or unexported fields
}
func (*PasetoMaker) CreateToken ¶
func (*PasetoMaker) VerifyToken ¶
func (maker *PasetoMaker) VerifyToken(token string) (*Payload, error)
Click to show internal directories.
Click to hide internal directories.