utils

package
v0.0.0-...-34759b2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	USD = "USD"
	INR = "INR"
	EUR = "EUR"
)

Variables

This section is empty.

Functions

func CheckPassword

func CheckPassword(password string, hashedPassword string) error

func HashPassword

func HashPassword(password string) (string, error)

func IsSupportedCurrency

func IsSupportedCurrency(currency string) bool

func RandomCurrency

func RandomCurrency() string

func RandomEmail

func RandomEmail() string

func RandomInt

func RandomInt(min, max int64) int64

func RandomMoney

func RandomMoney() int64

func RandomOwner

func RandomOwner() string

func RandomString

func RandomString(n int) string

Types

type Config

type Config struct {
	DBDriver            string        `mapstructure:"DB_DRIVER"`
	DBSource            string        `mapstructure:"DB_SOURCE"`
	ServerAddress       string        `mapstructure:"SERVER_ADDRESS"`
	TokenSymmetricKey   string        `mapstructure:"TOKEN_SYMMETRIC_KEY"`
	AccessTokenDuration time.Duration `mapstructure:"ACCESS_TOKEN_DURATION"`
}

Config stores all configuration of the application The values are read by viper from a config file or environment variables

func LoadConfig

func LoadConfig(path string) (config Config, err error)

Jump to